@@ -527,12 +527,22 @@ class log_monitor_manager {
         }
         
         // Add attempt to cache
+        $attempt_time = time();
         $this->attempts_cache[$key]['attempts'][] = array(
             'username' => $username,
-            'time' => time(),
+            'time' => $attempt_time,
             'log_line' => $log_line
         );
         
+        // Also save to database for statistics and reporting
+        $stmt = $this->db->prepare('INSERT INTO service_failed_attempts (service_type, ip_address, username, attempt_time, log_line) VALUES (?, ?, ?, ?, ?)');
+        $stmt->bindValue(1, $service, SQLITE3_TEXT);
+        $stmt->bindValue(2, $ip, SQLITE3_TEXT);
+        $stmt->bindValue(3, $username, SQLITE3_TEXT);
+        $stmt->bindValue(4, $attempt_time, SQLITE3_INTEGER);
+        $stmt->bindValue(5, $log_line, SQLITE3_TEXT);
+        $stmt->execute();
+        
         // Clean old attempts (older than 1 hour)
         $cutoff = time() - 3600;
         $this->attempts_cache[$key]['attempts'] = array_filter(
