@@ -346,11 +346,27 @@ class security_manager {
         $result = $stmt->execute();
         $blocked_count = $result->fetchArray(SQLITE3_ASSOC)['count'];
         
-        // Get failed attempts in last 24 hours
+        // Get failed attempts in last 24 hours from both old and new tables
+        $cutoff_time = time() - 86400;
+        
+        // Get from old failed_logins table
         $stmt = $this->db->prepare('SELECT COUNT(*) as count FROM failed_logins WHERE attempt_time > :time');
-        $stmt->bindValue(':time', time() - 86400, SQLITE3_INTEGER);
+        $stmt->bindValue(':time', $cutoff_time, SQLITE3_INTEGER);
         $result = $stmt->execute();
-        $failed_24h = $result->fetchArray(SQLITE3_ASSOC)['count'];
+        $failed_24h_old = $result->fetchArray(SQLITE3_ASSOC)['count'];
+        
+        // Get from new service_failed_attempts table (if it exists)
+        $failed_24h_new = 0;
+        try {
+            $stmt = $this->db->prepare('SELECT COUNT(*) as count FROM service_failed_attempts WHERE attempt_time > :time');
+            $stmt->bindValue(':time', $cutoff_time, SQLITE3_INTEGER);
+            $result = $stmt->execute();
+            $failed_24h_new = $result->fetchArray(SQLITE3_ASSOC)['count'];
+        } catch (Exception $e) {
+            // Table might not exist in older installations
+        }
+        
+        $failed_24h = $failed_24h_old + $failed_24h_new;
         
         // Get exemption list count
         $stmt = $this->db->prepare('SELECT COUNT(*) as count FROM whitelist_ips');
