@@ -511,14 +511,14 @@ $access_stats = $PermManager->get_system_access_stats(30);
                             <tr><th>IP Address</th><th width="120">Action</th></tr>
                         </thead>
                         <tbody>
-                            <?php foreach ($blocked_ips as $ip): ?>
+                            <?php foreach ($blocked_ips as $ip_data): ?>
                             <tr>
-                                <td><?php echo htmlspecialchars($ip); ?></td>
+                                <td><?php echo htmlspecialchars($ip_data['ip_address']); ?></td>
                                 <td>
                                     <form method="POST" action="" style="display:inline;">
                                         <input type="hidden" name="csrf_token" value="<?php echo get_csrf_token(); ?>">
                                         <input type="hidden" name="action" value="unblock_ip">
-                                        <input type="hidden" name="ip_address" value="<?php echo htmlspecialchars($ip); ?>">
+                                        <input type="hidden" name="ip_address" value="<?php echo htmlspecialchars($ip_data['ip_address']); ?>">
                                         <button type="submit" class="btn btn-warning btn-sm">Unblock</button>
                                     </form>
                                 </td>
